---
title: <span class="badge object-type-scalar"></span> NanogramPerCubicMeter
---
# <span class="badge object-type-scalar"></span> NanogramPerCubicMeter

Concentration: nanogram per cubic meter (ng/m³)

## Definition

```python
# Concentration: nanogram per cubic meter (ng/m³)
NanogramPerCubicMeter: typing.Literal["conngm3"] = "conngm3"
```
